function [observation_table] = dataAssociation(inrange,data_table,max_distance)
%INPUTS: observed features,landmark table, min_distance for new landmark
%OUTPUT: observed features corresponding to input landmark table

% NOTES: Uses variation of simple nearest neighbor method for data
%        association. New landmarks are always added on the end of the
%        data table, and new observations replace the corresponding
%        previous observations obtained from the data table.

if isempty(data_table)
    %% Accept All Features if No Data Table
    observation_table=inrange;
else
    observation_table=data_table;
    check=1;
    %% Find New Landmarks from Distance
    while check==1
        [lm_ids dist_error]=knnsearch_nodep(data_table,inrange);
        
        %check for new landmarks using maximum distance
        distIndex=unique(find(dist_error>max_distance)); %find indeinrange for new landmarks
        
        if ~isempty(distIndex)
            %add new landmarks to new landmark vector
            new_lm(1,1)=inrange(distIndex(1),1);
            new_lm(1,2)=inrange(distIndex(1),2);
            check=1;
            
            %remove new landmarks from inrange to calculate data associations
            inrange(distIndex(1),:)=[];

            %add new landmarks to data table
            observation_table=[[data_table]' new_lm']';
        else
            check=0; %no more landmarks to check
        end
    end
    
    %% Calculate Data Associations
    %search new list of visible landmarks
    [lm_ids dist_error]=knnsearch_nodep(data_table,inrange);
    
    %% Replace associations in data_table
    if(lm_ids>0)
        for i=length(lm_ids)
            index=lm_ids(i);
            observation_table(index,:)=inrange(i,:);
        end
    end
end

end

