function [z, H] = getMeasurement(pos, landmark_pos, observation_variance)
    %Observation Variance
    if observation_variance(1)~=0 %if variance is on
        observation_variance = [randgauss(0,0.125^2)/5; randgauss(0,0.125^2)];
    end

    %Calculate vector from the robot to the landmark
    vector_to_landmark = [landmark_pos(1) - pos(1),landmark_pos(2) - pos(2)]; 
    angle_to_landmark = atan2(vector_to_landmark(2),vector_to_landmark(1)); 

    %Calculate landmark location
    landmark_distance = sqrt((landmark_pos(1) - pos(1))^2.0 + (landmark_pos(2) - pos(2))^2.0);
    landmark_angle = angle_to_landmark;

    q = landmark_distance;

    % Jacobian for EKF
    H = [-(landmark_pos(1) - pos(1))/q,       -(landmark_pos(2) - pos(2))/q,       0.0;
        (landmark_pos(2) - pos(2))/q^2,     -(landmark_pos(1) - pos(1))/q^2,    -1.0;
        0.0,                                0.0,                                 1.0];

    % Landmark Measurements Vector
    z = [landmark_distance;
      landmark_angle;
      0];
end
