% Sample Simulation with SMART Robot Data

% This file with show the output and FastSLAM
% modeling of a robots motion path

% This file is not required to run the simulation but instead serves
% as an example file on how to call the simulation itself.
% The simulation itself only requires that it be given the wheel velocities
% and the time since the last call to slamsim_withFastSLAM.

% This sample file passes specific IMU data to increase the accuracy of the
% simulation. The simulation itself can be called without IMU data to only
% use dead reckoning. (By setting the use_velocity_model boolean to true.)

clear all; close all; clc;
global FS % grab the global data var
load('BigData_60s_run2.mat')

vel= cell2mat(BigData(:,2));
m = length(vel);
vel_l = vel(1:2:m);
vel_r = vel(2:2:m);
clear vel m
[m,~]=size(vel_r);

slamsim_withFastSLAM([], [], [], [], 1); % init particles etc

for i=1:m
    SD2.R=SD.R(1,i); % Yaw gyro update from the IMU
    SD2.X=SD.X(1,i); % Calculated X position from INU
    SD2.Y=SD.Y(1,i); % Calculated Y position from IMU
    SD2.LaserScan=fliplr(SD.LaserScan(i,:)); % laserscan data
    slamsim_withFastSLAM(SD.Time_Diff(i), vel_r(i), vel_l(i), SD2, 0)
end

% Output Map of Occupancy Grid
figure, imagesc(rot90(FS.map))
title('Occupancy Grid of Map');